"""
Mapping module for Salesforce Toolkit.

Provides flexible field mapping and data transformation capabilities.
"""

from kinetic_core.mapping.field_mapper import FieldMapper, ConditionalFieldMapper

__all__ = ["FieldMapper", "ConditionalFieldMapper"]
